
## 安装教程

> [MeEdu常见问题总结及功能介绍](https://www.yuque.com/meedu/yr7rek)

#### 环境要求

+ Composer
+ PHP >= 7.2
+ MySql >= 5.6
+ Zip PHP Extension
+ OpenSSL PHP Extension
+ PDOMysql PHP Extension
+ Mbstring PHP Extension
+ Tokenizer PHP Extension
+ XML PHP Extension
+ Fileinfo PHP Extension

## 步骤

#### 步骤一

安装 meedu

```
composer create-project qsnh/meedu
```

#### 步骤二

生成JWT秘钥：

```
php artisan key:generate
php artisan jwt:secret
```

配置数据库，打开 .env 文件，修改下面的内容：

```
DB_CONNECTION=mysql
DB_HOST=127.0.0.1
DB_PORT=3306
DB_DATABASE=homestead
DB_USERNAME=homestead
DB_PASSWORD=secret
```

配置基本信息

```
APP_NAME=MeEdu
APP_ENV=local(这里如果正式运行，请修改为：production)
APP_KEY=
APP_DEBUG=true(这里如果是正式运行，请修改为：false)
APP_LOG_LEVEL=debug
APP_URL=http://localhost(这里修改你自己的地址)
```

#### 步骤三

创建上传目录软链接：

```
php artisan storage:link
```

#### 步骤四

设置 `storage` 目录权限为 `777`

```
chmod -R  0777 storage
```

#### 步骤五

配置伪静态并设置 meedu 的运行目录为 `public` 。

伪静态规则（Nginx）：

```
location / {  
	try_files $uri $uri/ /index.php$is_args$query_string;  
}
```

#### 步骤六

安装数据表

```
php artisan migrate
```

#### 步骤七

初始化系统权限：

```
php artisan install role
```

初始化管理员：

```
php artisan install administrator
```

> 安装提示输入管理员的账号和密码！

#### 步骤八

到这里，MeEdu 基本上就安装完成了。但是，想要访问 MeEdu 的后台，您还需要安装 MeEdu 的后台的前端项目，地址：
[https://github.com/Meedu/backend](https://github.com/Meedu/backend) 。请按照该项目的说明进行安装。

## 如果正式在生产环境使用MeEdu，下面还需要配置

#### 步骤九

配置任务调度器：

将下面内容添加到 crontab 计划任务中：

```
* * * * * php /path-to-your-project/artisan schedule:run >> /dev/null 2>&1
```

> 注意替换其中的路径为meedu所在路径


### 步骤十

配置队列监听器：

首先，安装 supervisor :

```
sudo apt install supervisor
```

配置 supervisor 

```
cd /etc/supervisor/conf.d
vi meedu.conf
```

将下面的内容粘贴进去：

```
[program:meedu]
process_name=%(program_name)s_%(process_num)02d
command=php /you-project-path/artisan queue:work --sleep=3 --tries=3
autostart=true
autorestart=true
user=root
numprocs=1
redirect_stderr=true
stdout_logfile=/you-project-path/storage/logs/supervisor.log
```

> 注意替换其中的路径和user

重启服务：

```angular2html
sudo supervisorctl reread
sudo supervisorctl update
sudo supervisorctl start meedu:*
```

如果配置正确，你会看到 supervisor 的输出日志，日志路径就是上面配置的 stdout_logfile 的值。

## 常见问题

#### Mysql8数据库

mysql8 默认的配置改为default-authentication-plugin=mysql_native_password